Documentation
¶
Index ¶
- func EndBlocker(ctx context.Context, k keeper.Keeper) error
- func ProvideModule(in FeegrantInputs) (keeper.Keeper, appmodule.AppModule)
- type AppModule
- func (am AppModule) AutoCLIOptions() *autocliv1.ModuleOptions
- func (AppModule) ConsensusVersion() uint64
- func (am AppModule) EndBlock(ctx context.Context) error
- func (am AppModule) ExportGenesis(ctx sdk.Context, cdc codec.JSONCodec) json.RawMessage
- func (AppModule) GenerateGenesisState(simState *module.SimulationState)
- func (am AppModule) InitGenesis(ctx sdk.Context, cdc codec.JSONCodec, bz json.RawMessage)
- func (am AppModule) IsAppModule()
- func (am AppModule) IsOnePerModuleType()
- func (am AppModule) RegisterServices(cfg module.Configurator)
- func (am AppModule) RegisterStoreDecoder(sdr simtypes.StoreDecoderRegistry)
- func (am AppModule) WeightedOperations(simState module.SimulationState) []simtypes.WeightedOperation
- func (am AppModule) WeightedOperationsX(weights simsx.WeightSource, reg simsx.Registry)
- type AppModuleBasic
- func (ab AppModuleBasic) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
- func (ab AppModuleBasic) GetTxCmd() *cobra.Command
- func (ab AppModuleBasic) Name() string
- func (ab AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx sdkclient.Context, mux *gwruntime.ServeMux)
- func (ab AppModuleBasic) RegisterInterfaces(registry cdctypes.InterfaceRegistry)
- func (ab AppModuleBasic) RegisterLegacyAminoCodec(cdc *codec.LegacyAmino)
- func (ab AppModuleBasic) ValidateGenesis(cdc codec.JSONCodec, config sdkclient.TxEncodingConfig, bz json.RawMessage) error
- type FeegrantInputs
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProvideModule ¶
func ProvideModule(in FeegrantInputs) (keeper.Keeper, appmodule.AppModule)
Types ¶
type AppModule ¶
type AppModule struct {
AppModuleBasic
// contains filtered or unexported fields
}
AppModule implements an application module for the feegrant module.
func NewAppModule ¶
func NewAppModule(cdc codec.Codec, ak feegrant.AccountKeeper, bk feegrant.BankKeeper, keeper keeper.Keeper, registry cdctypes.InterfaceRegistry) AppModule
NewAppModule creates a new AppModule object
func (AppModule) AutoCLIOptions ¶
func (am AppModule) AutoCLIOptions() *autocliv1.ModuleOptions
func (AppModule) ConsensusVersion ¶
ConsensusVersion implements AppModule/ConsensusVersion.
func (AppModule) EndBlock ¶
EndBlock returns the end blocker for the feegrant module. It returns no validator updates.
func (AppModule) ExportGenesis ¶
ExportGenesis returns the exported genesis state as raw bytes for the feegrant module.
func (AppModule) GenerateGenesisState ¶
func (AppModule) GenerateGenesisState(simState *module.SimulationState)
GenerateGenesisState creates a randomized GenState of the feegrant module.
func (AppModule) InitGenesis ¶
InitGenesis performs genesis initialization for the feegrant module. It returns no validator updates.
func (AppModule) IsAppModule ¶
func (am AppModule) IsAppModule()
IsAppModule implements the appmodule.AppModule interface.
func (AppModule) IsOnePerModuleType ¶
func (am AppModule) IsOnePerModuleType()
IsOnePerModuleType implements the depinject.OnePerModuleType interface.
func (AppModule) RegisterServices ¶
func (am AppModule) RegisterServices(cfg module.Configurator)
RegisterServices registers a gRPC query service to respond to the module-specific gRPC queries.
func (AppModule) RegisterStoreDecoder ¶
func (am AppModule) RegisterStoreDecoder(sdr simtypes.StoreDecoderRegistry)
RegisterStoreDecoder registers a decoder for feegrant module's types
func (AppModule) WeightedOperations ¶
func (am AppModule) WeightedOperations(simState module.SimulationState) []simtypes.WeightedOperation
WeightedOperations returns all the feegrant module operations with their respective weights. migrate to WeightedOperationsX. This method is ignored when WeightedOperationsX exists and will be removed in the future
func (AppModule) WeightedOperationsX ¶ added in v0.2.0
func (am AppModule) WeightedOperationsX(weights simsx.WeightSource, reg simsx.Registry)
WeightedOperationsX registers weighted feegrant module operations for simulation.
type AppModuleBasic ¶
type AppModuleBasic struct {
// contains filtered or unexported fields
}
AppModuleBasic defines the basic application module used by the feegrant module.
func (AppModuleBasic) DefaultGenesis ¶
func (ab AppModuleBasic) DefaultGenesis(cdc codec.JSONCodec) json.RawMessage
DefaultGenesis returns default genesis state as raw bytes for the feegrant module.
func (AppModuleBasic) GetTxCmd ¶
func (ab AppModuleBasic) GetTxCmd() *cobra.Command
GetTxCmd returns the root tx command for the feegrant module.
func (AppModuleBasic) Name ¶
func (ab AppModuleBasic) Name() string
Name returns the feegrant module's name.
func (AppModuleBasic) RegisterGRPCGatewayRoutes ¶
func (ab AppModuleBasic) RegisterGRPCGatewayRoutes(clientCtx sdkclient.Context, mux *gwruntime.ServeMux)
RegisterGRPCGatewayRoutes registers the gRPC Gateway routes for the feegrant module.
func (AppModuleBasic) RegisterInterfaces ¶
func (ab AppModuleBasic) RegisterInterfaces(registry cdctypes.InterfaceRegistry)
RegisterInterfaces registers the feegrant module's interface types
func (AppModuleBasic) RegisterLegacyAminoCodec ¶
func (ab AppModuleBasic) RegisterLegacyAminoCodec(cdc *codec.LegacyAmino)
RegisterLegacyAminoCodec registers the feegrant module's types for the given codec.
func (AppModuleBasic) ValidateGenesis ¶
func (ab AppModuleBasic) ValidateGenesis(cdc codec.JSONCodec, config sdkclient.TxEncodingConfig, bz json.RawMessage) error
ValidateGenesis performs genesis state validation for the feegrant module.
type FeegrantInputs ¶
type FeegrantInputs struct {
depinject.In
StoreService store.KVStoreService
Cdc codec.Codec
AccountKeeper feegrant.AccountKeeper
BankKeeper feegrant.BankKeeper
Registry cdctypes.InterfaceRegistry
}