Documentation
¶
Index ¶
- Constants
- Variables
- func MsgGrantAllowanceFactory(k keeper.Keeper) simsx.SimMsgFactoryFn[*feegrant.MsgGrantAllowance]
- func MsgRevokeAllowanceFactory(k keeper.Keeper) simsx.SimMsgFactoryFn[*feegrant.MsgRevokeAllowance]
- func NewDecodeStore(cdc codec.Codec) func(kvA, kvB kv.Pair) string
- func RandomizedGenState(simState *module.SimulationState)
- func SimulateMsgGrantAllowance(cdc *codec.ProtoCodec, txConfig client.TxConfig, ak feegrant.AccountKeeper, ...) simtypes.Operation
- func SimulateMsgRevokeAllowance(cdc *codec.ProtoCodec, txConfig client.TxConfig, ak feegrant.AccountKeeper, ...) simtypes.Operation
- func WeightedOperations(registry codectypes.InterfaceRegistry, appParams simtypes.AppParams, ...) simulation.WeightedOperations
Constants ¶
const ( OpWeightMsgGrantAllowance = "op_weight_msg_grant_fee_allowance" OpWeightMsgRevokeAllowance = "op_weight_msg_grant_revoke_allowance" DefaultWeightGrantAllowance int = 100 DefaultWeightRevokeAllowance int = 100 )
Simulation operation weights constants will be removed in the future
Variables ¶
var ( TypeMsgGrantAllowance = sdk.MsgTypeURL(&feegrant.MsgGrantAllowance{}) TypeMsgRevokeAllowance = sdk.MsgTypeURL(&feegrant.MsgRevokeAllowance{}) )
will be removed in the future
Functions ¶
func MsgGrantAllowanceFactory ¶ added in v0.2.0
func MsgGrantAllowanceFactory(k keeper.Keeper) simsx.SimMsgFactoryFn[*feegrant.MsgGrantAllowance]
func MsgRevokeAllowanceFactory ¶ added in v0.2.0
func MsgRevokeAllowanceFactory(k keeper.Keeper) simsx.SimMsgFactoryFn[*feegrant.MsgRevokeAllowance]
func NewDecodeStore ¶
NewDecodeStore returns a decoder function closure that unmarshals the KVPair's Value to the corresponding feegrant type.
func RandomizedGenState ¶
func RandomizedGenState(simState *module.SimulationState)
RandomizedGenState generates a random GenesisState for feegrant
func SimulateMsgGrantAllowance ¶
func SimulateMsgGrantAllowance( cdc *codec.ProtoCodec, txConfig client.TxConfig, ak feegrant.AccountKeeper, bk feegrant.BankKeeper, k keeper.Keeper, ) simtypes.Operation
SimulateMsgGrantAllowance generates MsgGrantAllowance with random values. will be removed in the future in favor of msg factory
func SimulateMsgRevokeAllowance ¶
func SimulateMsgRevokeAllowance( cdc *codec.ProtoCodec, txConfig client.TxConfig, ak feegrant.AccountKeeper, bk feegrant.BankKeeper, k keeper.Keeper, ac address.Codec, ) simtypes.Operation
SimulateMsgRevokeAllowance generates a MsgRevokeAllowance with random values. will be removed in the future in favor of msg factory
func WeightedOperations ¶
func WeightedOperations( registry codectypes.InterfaceRegistry, appParams simtypes.AppParams, cdc codec.JSONCodec, txConfig client.TxConfig, ak feegrant.AccountKeeper, bk feegrant.BankKeeper, k keeper.Keeper, ac address.Codec, ) simulation.WeightedOperations
will be removed in the future in favor of msg factory
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.